@@ -119,7 +119,7 @@ class SqliteDataStore(DummyDataStore):
     sql_individuals_select = "SELECT * FROM individuals;"
     # SELECT json_extract(individual, '$.costs[0]') as cost FROM individuals where cost>10;
 
-    def __init__(self, problem, database_name, mode="write", thread_safe=False):
+    def __init__(self, problem, database_name, mode="write", thread_safe=True):
         self.problem = problem
         self.database_name = database_name
         self.mode = mode
@@ -243,8 +243,13 @@ class SqliteDataStore(DummyDataStore):
             c = conn.cursor()
 
             # data
-            c.execute(self.sql_individuals_upsert, [individual.id, json.dumps(individual.to_dict())])
-            conn.commit()
+            try:
+                c.execute(self.sql_individuals_upsert, [individual.id, json.dumps(individual.to_dict())])
+                conn.commit()
+            except sqlite3.OperationalError as e:
+                # try again
+                print("XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX ERROR")
+                self.sync_individual(individual)
 
 
 class TinyDataStore(DummyDataStore):
